@@ -650,9 +650,7 @@ def list(ctx, *args, **kwargs):
     The following commands can further filter shown todos, or include those
     omited by default:
     """
-    hide_list = (len([_ for _ in ctx.db.lists()]) == 1) or (  # noqa: C416
-        len(kwargs["lists"]) == 1
-    )
+    hide_list = (len([_ for _ in ctx.db.lists()]) == 1) or (len(kwargs["lists"]) == 1)
 
     kwargs["categories"] = kwargs.pop("category")
 
